@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/aclock.h   3.1.2   edited Nov 8 10:35 $
+** $Id: qt/aclock.h   3.3.2   edited Dec 10 16:29 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -14,30 +14,31 @@
 #include <qwidget.h>
 #include <qdatetime.h>
 
-
+class QTimer;
 class AnalogClock : public QWidget		// analog clock widget
 {
     Q_OBJECT
 public:
     AnalogClock( QWidget *parent=0, const char *name=0 );
     void setAutoMask(bool b);
-
-public slots:    
-    void setTime( const QTime & t );
     
 protected:
     void updateMask();
     void paintEvent( QPaintEvent *);
     void mousePressEvent( QMouseEvent *);
     void mouseMoveEvent( QMouseEvent *);
+    void drawClock( QPainter* );
     
 private slots:
-    void drawClock( QPainter* );
-    void	timeout();
+    void timeout();
+
+public slots:
+    void setTime( const QTime & t );
 
 private:
     QPoint clickPos;
-    QTime	time;
+    QTime time;
+    QTimer *internalTimer;
 };
 
 
