@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qpainter.h   3.3.0   edited Nov 12 13:57 $
+** $Id: qt/qpainter.h   3.3.2   edited Feb 3 23:50 $
 **
 ** Definition of QPainter class
 **
@@ -300,11 +300,7 @@ private:
     void	map( int, int, int, int, int *, int *, int *, int * ) const;
     void	mapInv( int, int, int *, int * ) const;
     void	mapInv( int, int, int, int, int *, int *, int *, int * ) const;
-#ifdef Q_WS_MACX
-    void	drawPolyInternal( const QPointArray &, bool close=TRUE, bool inset=TRUE );
-#else
     void	drawPolyInternal( const QPointArray &, bool close=TRUE );
-#endif
     void	drawWinFocusRect( int x, int y, int w, int h, bool xorPaint,
 				  const QColor &penColor );
 
