@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qstring.h   3.3.0   edited Nov 7 12:08 $
+** $Id: qt/qstring.h   3.3.2   edited Mar 31 13:28 $
 **
 ** Definition of the QString class, and related Unicode functions.
 **
@@ -193,7 +193,11 @@ public:
 
     char latin1() const { return ucs > 0xff ? 0 : (char) ucs; }
     ushort unicode() const { return ucs; }
+#ifdef Q_NO_PACKED_REFERENCE
+    ushort &unicode() { return *(&ucs); }
+#else
     ushort &unicode() { return ucs; }
+#endif
 #ifndef QT_NO_CAST_ASCII
     // like all ifdef'd code this is undocumented
     operator char() const { return latin1(); }
